@@ -919,7 +919,7 @@ create_notification(UrlClickedCb url_clicked)
 	gtk_label_set_xalign (GTK_LABEL (windata->summary_label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (windata->summary_label), 0.0);
 #else
-	gtk_misc_set_alignment(GTK_MISC(windata->summary_label), 0, 0);
+	gtk_misc_set_alignment(GTK_MISC(windata->summary_label), 0.0, 0.0);
 #endif
 	gtk_label_set_line_wrap(GTK_LABEL(windata->summary_label), TRUE);
 	gtk_label_set_line_wrap_mode (GTK_LABEL (windata->summary_label), PANGO_WRAP_WORD_CHAR);
@@ -943,11 +943,7 @@ create_notification(UrlClickedCb url_clicked)
 	atk_object_set_name(atkobj, "");
 	atk_object_set_description(atkobj, "Closes the notification.");
 
-#if GTK_CHECK_VERSION (3, 10, 0)
 	image = gtk_image_new_from_icon_name ("window-close", GTK_ICON_SIZE_MENU);
-#else
-	image = gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-#endif
 	gtk_widget_show(image);
 	gtk_container_add(GTK_CONTAINER(close_button), image);
 
@@ -963,11 +959,11 @@ create_notification(UrlClickedCb url_clicked)
 	windata->icon = gtk_image_new();
 	gtk_box_pack_start(GTK_BOX(windata->iconbox), windata->icon,
 					   TRUE, TRUE, 0);
-#if GTK_CHECK_VERSION (3, 16, 0)
-		gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
-		gtk_widget_set_valign (image, GTK_ALIGN_CENTER);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+	gtk_widget_set_valign (image, GTK_ALIGN_CENTER);
 #else
-		gtk_misc_set_alignment(GTK_MISC(image), 0.5, 0.5);
+	gtk_misc_set_alignment(GTK_MISC(image), 0.5, 0.5);
 #endif
 
 	vbox = gtk_vbox_new(FALSE, 6);
@@ -980,10 +976,13 @@ create_notification(UrlClickedCb url_clicked)
 	gtk_label_set_xalign (GTK_LABEL (windata->body_label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (windata->body_label), 0.0);
 #else
-	gtk_misc_set_alignment(GTK_MISC(windata->body_label), 0, 0);
+	gtk_misc_set_alignment(GTK_MISC(windata->body_label), 0.0, 0.0);
 #endif
 	gtk_label_set_line_wrap(GTK_LABEL(windata->body_label), TRUE);
 	gtk_label_set_line_wrap_mode (GTK_LABEL (windata->body_label), PANGO_WRAP_WORD_CHAR);
+#if GTK_CHECK_VERSION (3, 0, 0)
+    gtk_label_set_max_width_chars (GTK_LABEL (windata->body_label), 50);
+#endif
 
 	g_signal_connect(G_OBJECT(windata->body_label), "activate-link",
                          G_CALLBACK(activate_link), windata);
@@ -1134,7 +1133,7 @@ add_notification_action(GtkWindow *nw, const char *text, const char *key,
 		GtkWidget *image = gtk_image_new_from_pixbuf(pixbuf);
 		gtk_widget_show(image);
 		gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 0);
-#if GTK_CHECK_VERSION (3, 16, 0)
+#if GTK_CHECK_VERSION (3, 0, 0)
 		gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
 		gtk_widget_set_valign (image, GTK_ALIGN_CENTER);
 #else
@@ -1147,8 +1146,9 @@ add_notification_action(GtkWindow *nw, const char *text, const char *key,
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 #if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+	gtk_label_set_yalign (GTK_LABEL (label), 0.5);
 #else
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
 #endif
 	buf = g_strdup_printf("<small>%s</small>", text);
 	gtk_label_set_markup(GTK_LABEL(label), buf);
