@@ -131,6 +131,26 @@ static void draw_round_rect(cairo_t* cr, gdouble aspect, gdouble x, gdouble y, g
 	cairo_arc(cr, x + radius, y + radius, radius, 180.0f * G_PI / 180.0f, 270.0f * G_PI / 180.0f);
 }
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+static void
+get_background_color (GtkStyleContext *context,
+                      GtkStateFlags    state,
+                      GdkRGBA         *color)
+{
+    GdkRGBA *c;
+
+    g_return_if_fail (color != NULL);
+    g_return_if_fail (GTK_IS_STYLE_CONTEXT (context));
+
+    gtk_style_context_get (context,
+                           state,
+                           "background-color", &c,
+                           NULL);
+    *color = *c;
+    gdk_rgba_free (c);
+}
+#endif
+
 static void fill_background(GtkWidget* widget, WindowData* windata, cairo_t* cr)
 {
 	GtkAllocation allocation;
@@ -151,7 +171,7 @@ static void fill_background(GtkWidget* widget, WindowData* windata, cairo_t* cr)
 #if GTK_CHECK_VERSION(3, 0, 0)
 	context = gtk_widget_get_style_context(widget);
 
-	gtk_style_context_get_background_color (context, GTK_STATE_FLAG_NORMAL, &bg_color);
+	get_background_color (context, GTK_STATE_FLAG_NORMAL, &bg_color);
 	r = bg_color.red;
 	g = bg_color.green;
 	b = bg_color.blue;
@@ -399,11 +419,8 @@ static void on_window_realize(GtkWidget* widget, WindowData* windata)
 	/* Nothing */
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-static void color_reverse(const GdkRGBA* a, GdkRGBA* b)
-#else
+#if !GTK_CHECK_VERSION (3, 0, 0)
 static void color_reverse(const GdkColor* a, GdkColor* b)
-#endif
 {
 	gdouble red;
 	gdouble green;
@@ -412,15 +429,9 @@ static void color_reverse(const GdkColor* a, GdkColor* b)
 	gdouble s;
 	gdouble v;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-	red = a->red;
-	green = a->green;
-	blue = a->blue;
-#else
 	red = (gdouble) a->red / 65535.0;
 	green = (gdouble) a->green / 65535.0;
 	blue = (gdouble) a->blue / 65535.0;
-#endif
 
 	gtk_rgb_to_hsv(red, green, blue, &h, &s, &v);
 
@@ -441,16 +452,11 @@ static void color_reverse(const GdkColor* a, GdkColor* b)
 
 	gtk_hsv_to_rgb(h, s, v, &red, &green, &blue);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-	b->red = red;
-	b->green = green;
-	b->blue = blue;
-#else
 	b->red = red * 65535.0;
 	b->green = green * 65535.0;
 	b->blue = blue * 65535.0;
-#endif
 }
+#endif
 #if GTK_CHECK_VERSION (3, 0, 0)
 static GtkStateFlags state_flags_from_type (GtkStateType state)
 {
@@ -504,10 +510,10 @@ static void override_style(GtkWidget* widget)
 		flags = state_flags_from_type (state);
 
 		gtk_style_context_get_color (context, flags, &fg);
-		gtk_style_context_get_background_color (context, flags, &bg);
+		get_background_color (context, flags, &bg);
 
-		color_reverse(&fg, &fg2);
-		color_reverse(&bg, &bg2);
+		fg2 = fg;
+		bg2 = bg;
 
 		gtk_widget_override_color (widget, flags, &fg2);
 		gtk_widget_override_background_color (widget, flags, &bg2);
@@ -664,9 +670,7 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 	g_signal_connect(G_OBJECT(win), "configure-event", G_CALLBACK(on_configure_event), windata);
 
 	main_vbox = gtk_vbox_new(FALSE, 0);
-#if GTK_CHECK_VERSION (3, 0, 0)
-	g_signal_connect(G_OBJECT(main_vbox), "style-updated", G_CALLBACK(on_style_updated), windata);
-#else
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	g_signal_connect(G_OBJECT(main_vbox), "style-set", G_CALLBACK(on_style_set), windata);
 #endif
 	gtk_widget_show(main_vbox);
@@ -699,9 +703,7 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 	gtk_box_pack_start(GTK_BOX(windata->main_hbox), alignment, FALSE, FALSE, 0);
 
 	close_button = gtk_button_new();
-#if GTK_CHECK_VERSION (3, 0, 0)
-	g_signal_connect(G_OBJECT(close_button), "style-updated", G_CALLBACK(on_style_updated), windata);
-#else
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	g_signal_connect(G_OBJECT(close_button), "style-set", G_CALLBACK(on_style_set), windata);
 #endif
 	gtk_widget_show(close_button);
@@ -723,19 +725,13 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 	atk_object_set_name(atkobj, "");
 	atk_object_set_description(atkobj, "Closes the notification.");
 
-#if GTK_CHECK_VERSION (3, 10, 0)
 	image = gtk_image_new_from_icon_name ("window-close", GTK_ICON_SIZE_MENU);
-#else
-	image = gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-#endif
 	gtk_widget_show(image);
 	gtk_container_add(GTK_CONTAINER(close_button), image);
 
 	/* center vbox */
 	windata->summary_label = gtk_label_new(NULL);
-#if GTK_CHECK_VERSION (3, 0, 0)
-	g_signal_connect(G_OBJECT(windata->summary_label), "style-updated", G_CALLBACK(on_style_updated), windata);
-#else
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	g_signal_connect(G_OBJECT(windata->summary_label), "style-set", G_CALLBACK(on_style_set), windata);
 #endif
 	gtk_widget_show(windata->summary_label);
@@ -744,7 +740,7 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 	gtk_label_set_xalign (GTK_LABEL (windata->summary_label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (windata->summary_label), 0.0);
 #else
-	gtk_misc_set_alignment(GTK_MISC(windata->summary_label), 0, 0);
+	gtk_misc_set_alignment(GTK_MISC(windata->summary_label), 0.0, 0.0);
 #endif
 	gtk_label_set_line_wrap(GTK_LABEL(windata->summary_label), TRUE);
 #if GTK_CHECK_VERSION (3, 0, 0)
@@ -764,9 +760,7 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 	gtk_box_pack_start(GTK_BOX(windata->content_hbox), vbox, TRUE, TRUE, 0);
 
 	windata->body_label = gtk_label_new(NULL);
-#if GTK_CHECK_VERSION (3, 0, 0)
-	g_signal_connect(G_OBJECT(windata->body_label), "style-updated", G_CALLBACK(on_style_updated), windata);
-#else
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	g_signal_connect(G_OBJECT(windata->body_label), "style-set", G_CALLBACK(on_style_set), windata);
 #endif
 	gtk_widget_show(windata->body_label);
@@ -775,11 +769,12 @@ GtkWindow* create_notification(UrlClickedCb url_clicked)
 	gtk_label_set_xalign (GTK_LABEL (windata->body_label), 0.0);
 	gtk_label_set_yalign (GTK_LABEL (windata->body_label), 0.0);
 #else
-	gtk_misc_set_alignment(GTK_MISC(windata->body_label), 0, 0);
+	gtk_misc_set_alignment(GTK_MISC(windata->body_label), 0.0, 0.0);
 #endif
 	gtk_label_set_line_wrap(GTK_LABEL(windata->body_label), TRUE);
 #if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_label_set_line_wrap_mode (GTK_LABEL (windata->body_label), PANGO_WRAP_WORD_CHAR);
+    gtk_label_set_max_width_chars (GTK_LABEL (windata->body_label), 50);
 #endif
 	g_signal_connect_swapped(G_OBJECT(windata->body_label), "activate-link", G_CALLBACK(windata->url_clicked), win);
 
@@ -1010,7 +1005,7 @@ static gboolean on_countdown_expose(GtkWidget* pie, GdkEventExpose* event, Windo
 	cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
 #if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_style_context_get_color (style, GTK_STATE_FLAG_NORMAL, &color);
-	gtk_style_context_get_background_color (style, GTK_STATE_FLAG_NORMAL, &fg_color);
+	get_background_color (style, GTK_STATE_FLAG_NORMAL, &fg_color);
 	r = color.red;
 	g = color.green;
 	b = color.blue;
@@ -1079,9 +1074,7 @@ void add_notification_action(GtkWindow* nw, const char* text, const char* key, A
 		gtk_box_pack_end(GTK_BOX(windata->actions_box), alignment, FALSE, TRUE, 0);
 
 		windata->pie_countdown = gtk_drawing_area_new();
-#if GTK_CHECK_VERSION (3, 0, 0)
-		g_signal_connect(G_OBJECT(windata->pie_countdown), "style-updated", G_CALLBACK(on_style_updated), windata);
-#else
+#if !GTK_CHECK_VERSION (3, 0, 0)
 		g_signal_connect(G_OBJECT(windata->pie_countdown), "style-set", G_CALLBACK(on_style_set), windata);
 #endif
 
@@ -1096,9 +1089,7 @@ void add_notification_action(GtkWindow* nw, const char* text, const char* key, A
 	}
 
 	button = gtk_button_new();
-#if GTK_CHECK_VERSION (3, 0, 0)
-	g_signal_connect(G_OBJECT(button), "style-updated", G_CALLBACK(on_style_updated), windata);
-#else
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	g_signal_connect(G_OBJECT(button), "style-set", G_CALLBACK(on_style_set), windata);
 #endif
 	gtk_widget_show(button);
@@ -1119,14 +1110,12 @@ void add_notification_action(GtkWindow* nw, const char* text, const char* key, A
 	if (pixbuf != NULL)
 	{
 		GtkWidget* image = gtk_image_new_from_pixbuf(pixbuf);
-#if GTK_CHECK_VERSION (3, 0, 0)
-		g_signal_connect(G_OBJECT(image), "style-updated", G_CALLBACK(on_style_updated), windata);
-#else
+#if !GTK_CHECK_VERSION (3, 0, 0)
 		g_signal_connect(G_OBJECT(image), "style-set", G_CALLBACK(on_style_set), windata);
 #endif
 		gtk_widget_show(image);
 		gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 0);
-#if GTK_CHECK_VERSION (3, 16, 0)
+#if GTK_CHECK_VERSION (3, 0, 0)
 		gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
 		gtk_widget_set_valign (image, GTK_ALIGN_CENTER);
 #else
@@ -1135,17 +1124,16 @@ void add_notification_action(GtkWindow* nw, const char* text, const char* key, A
 	}
 
 	label = gtk_label_new(NULL);
-#if GTK_CHECK_VERSION (3, 0, 0)
-	g_signal_connect(G_OBJECT(label), "style-updated", G_CALLBACK(on_style_updated), windata);
-#else
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	g_signal_connect(G_OBJECT(label), "style-set", G_CALLBACK(on_style_set), windata);
 #endif
 	gtk_widget_show(label);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 #if GTK_CHECK_VERSION (3, 16, 0)
 	gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+	gtk_label_set_yalign (GTK_LABEL (label), 0.5);
 #else
-	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
 #endif
 	buf = g_strdup_printf("<small>%s</small>", text);
 	gtk_label_set_markup(GTK_LABEL(label), buf);
